#
# spec file for package fcoe-utils
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fcoe-utils
Url:            http://www.open-fcoe.org
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libpciaccess-devel
BuildRequires:  libtool
BuildRequires:  open-lldp-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
Requires:       device-mapper
Requires:       iproute
Requires:       open-lldp
%systemd_requires
Version:        1.0.32
Release:        lp150.1.8
Summary:        FCoE userspace management tools
License:        GPL-2.0
Group:          System/Daemons
# git://open-fcoe.org/fcoe/fcoe-utils.git
Source0:        %{name}-%{version}.tar.xz

# Patches to be upstreamed
Patch3:         0003-systemctl-cannot-start-fcoemon.socket.patch
Patch4:         0004-fcoemon-Correctly-handle-options-in-the-service-file.patch
Patch5:         0005-fcoe.service-Add-foreground-to-prevent-fcoemon-to-be.patch
Patch6:         0006-fipvlan-fixup-return-value-on-error.patch
Patch8:         0008-Use-correct-socket-for-fcoemon.socket.patch
Patch9:         0009-disable-Werror-building.patch
Patch12:        0012-fcoemon-Retry-fcm_link_getlink-on-EBUSY.patch

# Patches from Fedora
Patch101:       fcoe-utils-1.0.29-make.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Userspace tools to manage FibreChannel over Ethernet (FCoE)
connections.


%prep
%setup -q
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch8 -p1
%patch9 -p1
%patch12 -p1
%patch101 -p1

%build
autoreconf -vi
%configure
make %{?_smp_mflags}

%install
%make_install
# old init script
rm -rf %{buildroot}/etc/init.d

# unitfile
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcfcoe

# contrib files
mkdir -p %{buildroot}%{_libexecdir}/fcoe
for file in \
	contrib/*.sh \
	debug/*sh
	do install -m 755 ${file} %{buildroot}%{_libexecdir}/fcoe/
done

%pre
%service_add_pre fcoe.service
exit 0

%post
%service_add_post fcoe.service
%fillup_only -n fcoe
exit 0

%preun
%service_del_preun fcoe.service
exit 0

%postun
%service_del_postun fcoe.service
exit 0

%files
%defattr(-,root,root,-)
%doc README COPYING QUICKSTART
%{_sbindir}/*
%{_mandir}/man8/*
%{_unitdir}/fcoe.service
%{_unitdir}/fcoemon.socket
%{_sysconfdir}/fcoe/
%config(noreplace) %{_sysconfdir}/fcoe/config
%config(noreplace) %{_sysconfdir}/fcoe/cfg-ethx
%config %{_sysconfdir}/bash_completion.d/
%{_libexecdir}/fcoe/

%changelog
* Tue Apr 11 2017 jthumshirn@suse.com
- Disable Werror when building to work around a new GCC 7 warning. (bsc#1030244)
  + 0009-disable-Werror-building.patch
* Thu Feb  9 2017 jthumshirn@suse.com
- Update to latest upstream release (FATE#320515)
    Remove the following upstreamed patches:
  0007-fipvlan-clean-up-state-machine-for-pfd_add.patch
  0009-fcoemon.c-Add-a-check-to-verify-if-dcbd-is-to-be-ini.patch
  0010-fcoemon-fixup-log_nlmsg_error.patch
  0011-fcoemon-Add-debugging-message-for-recv.patch
  0013-Fallback-to-default-MAC-address-for-FIP.patch
  0014-fcoeadm-target-segfault-with-other-fc-storage-present.patch
* Mon Oct 24 2016 jthumshirn@suse.com
- Fix fcoeadm-t crash when other FC storage is present (bsc#1006027)
  * 0014-fcoeadm-target-segfault-with-other-fc-storage-present.patch
* Thu Jul 14 2016 hare@suse.de
- fcoemon cannot start FIP responder (bsc#988887)
  * 0010-fcoemon-fixup-log_nlmsg_error.patch
  * 0011-fcoemon-Add-debugging-message-for-recv.patch
  * 0012-fcoemon-Retry-fcm_link_getlink-on-EBUSY.patch
  * 0013-Fallback-to-default-MAC-address-for-FIP.patch
- Rediff patch
  * 0006-fipvlan-fixup-return-value-on-error.patch
- Rename patch
  * old: 0009-fcoemon-c-add-a-check-to-verify-if-dcbd-is-to-be-initialized-else-do-not-try-to-connect-to-dcbd-lldpad.patch
  * new: 0009-fcoemon.c-Add-a-check-to-verify-if-dcbd-is-to-be-ini.patch
- Fixup spec file to correctly refer to service_del_postun
* Tue Jun 21 2016 jthumshirn@suse.com
- Don't activate DCB on adapters which do DCB in Hardware (bsc#985816)
  + 0009-fcoemon-c-add-a-check-to-verify-if-dcbd-is-to-be-initialized-else-do-not-try-to-connect-to-dcbd-lldpad.patch
* Mon Feb  8 2016 jthumshirn@suse.com
- Update to version 1.0.31 (FATE#320515)
  * Removed merged patches:
    + 0001-fcoemon-Rework-daemonizing-and-error-handling.patch
    + 0002-fcoemon-fix-IEEE-state-machine.patch
    + 0009-fcoe-utils-Add-sysfs_hba-to-to-fcoemon_utils.patch
    + 0010-fcoeadm-Use-internal-sysfs-based-hba-lib-for-informa.patch
    + 0011-fcoeadm-Use-internal-sysfs-lib-to-display-target-and.patch
    + 0012-fcoeadm-Use-internal-sysfs-lib-to-display-port-stati.patch
    + 0013-fcoeadm-Get-rid-of-some-includes.patch
    + 0014-fcoemon-Use-internal-sysfs_hba-library.patch
    + 0015-libutil-remove-definition-of-sa_hex_format.patch
    + 0016-fcping-Convert-fcping-to-internal-sysfs-based-implem.patch
    + 0017-configure.ac-Remove-libHBAAPIv2-and-libhbalinux2.patch
    + 0018-support-multiple-connections.patch
    + 0019-fcoeadm_display-Fix-display-of-NPIV-ports.patch
* Mon Nov  2 2015 jthumshirn@suse.com
- Fix display of NPIV ports (bsc#951859)
  + 0019-fcoeadm_display-Fix-display-of-NPIV-ports.patch
* Fri Oct 16 2015 jthumshirn@suse.com
- Fix erroneous memory free corruption (bsc#950696)
  + 0019-fcping-fix-erroneous-memory-free.patch
* Thu Oct  1 2015 jthumshirn@suse.com
- Fix enumeration of FCoE connections (bsc#947587)
  + 0018-support-multiple-connections.patch
* Thu Aug 13 2015 jthumshirn@suse.com
- Fix segmentation fault (bsc#941577)
- Fix display of driver name and version (bsc#941566)
* Wed Aug 12 2015 jthumshirn@suse.com
- Replace libHBAAPI and libhbalinux by new internal implementation (FATE#319021)
* Mon Aug  3 2015 hare@suse.de
- Update to version 1.0.30 (FATE#318849)
  * Remove merged patches:
    + 0001-man-Fix-small-typo-regarding-fcf-option.patch
    + 0002-Don-t-call-AM_INIT_AUTOMAKE-twice.patch
    + 0003-fipvlan-fails-on-powerpc.patch
    + 0004-fipvlan-Only-shutdown-interfaces-if-no-vlans-are-cre.patch
    + 0005-fipvlan-start-VLAN-interface-from-netlink-handler.patch
    + 0006-fipvlan-Extract-create_missing_vlan-function-from-lo.patch
    + 0007-fipvlan-create-VLANs-from-netlink-handler.patch
    + 0008-fipvlan-Start-FCoE-from-netlink-handler.patch
    + 0009-fipvlan-Update-wait-loop-to-wait-for-VLANs.patch
    + 0010-fipvlan-Re-send-VLAN-discovery.patch
    + 0011-fipvlan-update-manpage.patch
    + 0012-fipvlan-Leave-link-up-if-requested.patch
    + 0013-fipvlan-Update-manpage-to-reflect-correct-timeout.patch
    + 0014-fipvlan-Do-not-shut-down-FCoE-connections-on-physica.patch
    + 0015-fipvlan-break-out-of-receive-loop-on-error.patch
    + 0016-fipvlan-handle-errors-from-fip-socket-creation.patch
    + 0017-fipvlan-filter-interfaces-from-rtnl_getlink.patch
    + 0018-Add-missing-DESTDIR-when-installing-bash-completion.patch
    + 0019-Fix-build-with-Wl-as-needed.patch
    + 0020-Fix-integer-formatting.patch
    + 0021-fcnsq-Fixup-help-text.patch
    + 0022-fcnsq-Fixup-64bit-integer-handling.patch
    + 0023-fcoemon-add-systemd-service-file.patch
    + 0024-fcoemon-systemd-socket-activation.patch
    + 0025-doc-Update-QUICKSTART-INSTALL-docs-for-systemd-init-.patch
    + 0026-FIPVLAN-Really-break-out-of-the-recv_loop-upon-fip_r.patch
    + 0027-man-Fix-typo-in-fcoemon-documentation.patch
    + 0032-fipvlan-Fix-crash-in-create_and_start_vlan.patch
    + 0033-fipvlan-suppress-warning-interface-already-exists.patch
    + 0034-fipvlan-do-not-crash-on-empty-MAC-address-in-lookup_.patch
  * Add new patches from upstream:
    + 0001-fcoemon-Rework-daemonizing-and-error-handling.patch
  * Rename patches:
    + 0002-fcoemon-fix-IEEE-state-machine.patch
    + 0003-systemctl-cannot-start-fcoemon.socket.patch
    + 0004-fcoemon-Correctly-handle-options-in-the-service-file.patch
    + 0005-fcoe.service-Add-foreground-to-prevent-fcoemon-to-be.patch
    + 0006-fipvlan-fixup-return-value-on-error.patch
    + 0007-fipvlan-clean-up-state-machine-for-pfd_add.patch
    + 0008-Use-correct-socket-for-fcoemon.socket.patch
* Mon Jul 28 2014 hare@suse.de
- Use correct socket name in fcoemon.socket (bnc#881205)
  * Add 0037-Use-correct-socket-for-fcoemon.socket.patch
* Thu May 15 2014 hare@suse.de
- Start fcoemon in foreground from service file (bnc#873269)
  * Add 0030-fcoe.service-Add-foreground-to-prevent-fcoemon-to-be.patch
- Fixup IEEE state machine
  * Add 0031-fcoemon-Fix-IEEE-state-machine.patch
- Fix fipvlan crash during booting (bnc#877275):
  * Add 0032-fipvlan-Fix-crash-in-create_and_start_vlan.patch
  * Add 0033-fipvlan-suppress-warning-interface-already-exists.patch
  * Add 0034-fipvlan-do-not-crash-on-empty-MAC-address-in-lookup_.patch
- Fixup warning messages during booting:
  * Add 0035-fipvlan-fixup-return-value-on-error.patch
  * Add 0036-fipvlan-clean-up-state-machine-for-pfd_add.patch
* Fri Apr 11 2014 lchiquitto@suse.de
- Remove obsolete file fcoe.config from sources
* Fri Apr 11 2014 hare@suse.de
- Replace patches with upstream version
  Remove: 0025-systemctl-cannot-start-fcoemon.socket.patch
  Add: 0028-systemctl-cannot-start-fcoemon.socket.patch
- Pull in patches from upstream:
  * Really break out of recv_loop in fipvlan (bnc#870300)
    Add: 0026-FIPVLAN-Really-break-out-of-the-recv_loop-upon-fip_r.patch
  * Update documentation
    Add: 0025-doc-Update-QUICKSTART-INSTALL-docs-for-systemd-init-.patch
    Add: 0027-man-Fix-typo-in-fcoemon-documentation.patch
- Add dependency on libhbalinux2 (bnc#873066)
- Correctly handle options when invoking fcoemon (bnc#872732)
  Add: 0029-fcoemon-Correctly-handle-options-in-the-service-file.patch
- Include bnx2fc to SUPPORTED_DRIVERS (bnc#872741)
* Fri Mar 21 2014 hare@suse.de
- Fixup fcoemon.socket definitions (bnc#869392)
  * Add patch 0025-systemctl-cannot-start-fcoemon.socket.patch
- Remove mkinitrd support
- Remove duplicate configuration file (bnc#869109)
* Wed Mar 12 2014 hare@suse.de
- Refresh patches with upstream version
- Require open-lldp rpm (bnc#864387)
* Fri Dec  6 2013 hare@suse.de
- Reshuffle patches for upstream integration:
  * Add patch 0018-Add-missing-DESTDIR-when-installing-bash-completion.patch
  * Add patch 0019-Fix-build-with-Wl-as-needed.patch
  * Add patch 0020-Fix-integer-formatting.patch
  * Add patch 0021-fcnsq-Fixup-help-text.patch
  * Add patch 0022-fcnsq-Fixup-64bit-integer-handling.patch
- Add systemd integration patches:
  * Add patch 0023-fcoemon-add-systemd-service-file.patch
  * Add patch 0024-fcoemon-systemd-socket-activation.patch
- Remove obsolete patch fcoe-utils-1.0.18-help.patch
- Remove obsolete patch fcoe-utils-1.0.28-format-strings.patch
- Remove obsolete patch fcoe-utils-1.0.28-systemd-doc.patch
- Remove obsolete patch fcoe-utils-1.0.29-as-needed.patch
* Fri Dec  6 2013 hare@suse.de
- Small fixes from upstream
  * Add patch 0001-man-Fix-small-typo-regarding-fcf-option.patch
  * Add patch 0002-Don-t-call-AM_INIT_AUTOMAKE-twice.patch
- Include fipvlan update from upstream/SLES11 SP3
  * Add patch 0003-fipvlan-fails-on-powerpc.patch
  * Add patch 0004-fipvlan-Only-shutdown-interfaces-if-no-vlans-are-cre.patch
  * Add patch 0005-fipvlan-start-VLAN-interface-from-netlink-handler.patch
  * Add patch 0006-fipvlan-Extract-create_missing_vlan-function-from-lo.patch
  * Add patch 0007-fipvlan-create-VLANs-from-netlink-handler.patch
  * Add patch 0008-fipvlan-Start-FCoE-from-netlink-handler.patch
  * Add patch 0009-fipvlan-Update-wait-loop-to-wait-for-VLANs.patch
  * Add patch 0010-fipvlan-Re-send-VLAN-discovery.patch
  * Add patch 0011-fipvlan-update-manpage.patch
  * Add patch 0012-fipvlan-Leave-link-up-if-requested.patch
  * Add patch 0013-fipvlan-Update-manpage-to-reflect-correct-timeout.patch
  * Add patch 0014-fipvlan-Do-not-shut-down-FCoE-connections-on-physica.patch
  * Add patch 0015-fipvlan-break-out-of-receive-loop-on-error.patch
  * Add patch 0016-fipvlan-handle-errors-from-fip-socket-creation.patch
  * Add patch 0017-fipvlan-filter-interfaces-from-rtnl_getlink.patch
* Thu Oct 10 2013 tchvatal@suse.com
- Redo the autotools patch to actually fix --as-needed build,
  should be upstreamed.
- Adds patch: fcoe-utils-1.0.29-as-needed.patch
- Removes patch: fcoe-utils-1.0.29-no-as-needed.patch
* Thu Oct 10 2013 tchvatal@suse.com
- Fix Requires we have just device-mapper, used wrong pkg name.
* Thu Oct 10 2013 hare@suse.de
- Disable --as-needed to fix build failures
- Use %%fillup for sysconfig file
- Fixup build dependencies
* Wed Oct  9 2013 tchvatal@suse.com
- Bump to 1.0.29 removing all our suse stuff.
  * Still does not build, requires packaging of other deps they
    provide in git repo to clone.
* Tue Jul 23 2013 ohering@suse.de
- Remove usage of absolute paths in initrd
- List all used binaries in programs tag
- Use new emergency function, related to other bug (bnc#809812)
- Remove unneeded mkdir in setup script, mkinitrd does it now
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Jul  6 2010 hare@suse.de
- Fix build on Factory.
* Tue Jul  6 2010 hare@suse.de
- Refresh patches.
* Tue Jul  6 2010 hare@suse.de
- Port from SLES11 SP1.
* Mon May 10 2010 hare@suse.de
- Fix EMC SAN MAC issue (bnc#603964)
* Mon Apr 26 2010 hare@suse.de
- fixes no lun display issue due to wrong check for target role
  (bnc#599421)
* Thu Apr  8 2010 hare@suse.de
- Resync with open-fcoe for RC3 (bnc#594212)
* Thu Mar 25 2010 hare@suse.de
- More fipvlan fixes for RC2 (bnc#590324)
- Update mkinitrd script to actually boot the system (bnc#590868)
* Tue Mar 23 2010 hare@suse.de
- Sync-up package with git tree for RC2 (bnc#590324)
- Compile against lldpad (bnc#590487)
* Mon Mar 15 2010 hare@suse.de
- Sync-up package with commit id
  9403c2aaac0b79d0d236ef9413cc88b7d6f7f04e (bnc#588150)
* Sun Mar 14 2010 ro@suse.de
- finally fix build
* Sat Mar 13 2010 ro@suse.de
- fix typo in specfile
* Fri Mar  5 2010 hare@suse.de
- Add option '-i' to fipvlan (bnc#585045)
- Add setup script /sbin/fcoe-setup (bnc#585045)
* Mon Feb 22 2010 hare@suse.de
- Fixup mkinitrd scripts (bnc#570643)
* Mon Feb 22 2010 hare@suse.de
- Sync-up package with git tree (bnc#581550)
* Fri Jan 22 2010 hare@suse.de
- Sync-up package with git commit id
  3f25915a92c308c5db352a7fe24092350498f179 (bnc#572686)
- fcoemon uses memcpy when copying path name (bnc#572893)
* Thu Jan 14 2010 hare@suse.de
- Reverse mkinitrd script naming (bnc#570643)
* Mon Jan 11 2010 hare@suse.de
- Sync-up package for git tree (bnc#569508)
* Thu Dec 17 2009 hare@suse.de
- Add commands to issue create,destroy,reset from fcoeadm
  through fcoemon (bnc#557495)
* Fri Dec  4 2009 hare@suse.de
- Update utilities with latest bugfixes (bnc#557495)
- Requires dcbd and libhbalinux2 for correct operation.
* Sun Nov 22 2009 ro@suse.de
- change buildreq to dcbd to fix build
* Mon Nov 16 2009 hare@suse.de
- Update to version 1.0.8 (FATE#306854)
* Wed Nov 11 2009 mcihar@suse.cz
- added mkinitrd support for booting FCoE (FATE#307444)
* Mon Feb 23 2009 sf@suse.de
- added Quickstart.SLES (bnc #478582)
  to document SLES specifics
* Wed Feb 11 2009 sf@suse.de
- corrected open-fcoe-bug-473116-fix-library-path.diff
  wrong library in /etc/hba.conf (bnc #473116)
* Mon Feb  9 2009 sf@suse.de
- add bug-473627_0001-fcoemon-service-fcoe-status-display-is-incorrect.patch
  (bnc #473627)
- add bug-473628_0002-fcoeadm-Incorrectly-checking-return-value-of-strstr.patch
  (bnc #473628)
- add open-fcoe-bug-473116-fix-library-path.diff
  (bnc #473116)
- add bug-473630_0003-fcoemon-Incorrectly-calling-SA_LOG_ERR.patch
  (bnc #473630)
- add bug-473127_0004-fcoemon-dcbd-starts-after-fcoe-starts-fcoemon-will.patch
  (bnc #473127)
- add bug-473631_0005-fcoemon-Put-back-the-FCD_SEND_CONF-state.patch
  (bnc #473631)
* Sat Jan 24 2009 sf@suse.de
- rediffed open-fcoe-update-1.0.4.diff
- rediffed open-fcoe-multi-arch.diff
  due to not matching later patches:
- open-fcoe-update-1.0.6.diff
  (bnc #459142)
- 0001-fcoemon-Ensure-pfc-advertise-on-and-pg-advertise-of.patch
  (bnc #468457)
- 0002-fcoemon-Remove-the-FCD_SEND_CONF-state.patch
  (bnc # 468459)
- 0003-fcoemon-Verify-link-flow-control-if-DCB-is-not-requ.patch
  (bnc #468463)
- 0004-fcoemon-Don-t-check-errors-when-modprobe-fcoe.patch
  (bnc #468466)
- 0005-fcoemon-Fix-errors-in-configure_dcb_interface-of.patch
  (bnc # 468467)
- 0006-fcoemon-GET_PFC_CONFIG-command-is-not-issued-when-s.patch
  (bnc #468468)
- open-fcoe-fixes.diff
  (bnc #465598)
- open-fcoe-config.diff
  move device configuration from Makefile to initscript
- open-fcoe-multi-arch2.diff
  remove arch-check from Makefile
* Mon Jan 12 2009 sf@suse.de
- fixes for initscript (bnc #460021) and
  configuration paths (bnc #460022)
* Mon Dec  1 2008 sf@suse.de
- update to 10.4 (bnc #438954)
  - new patch from Intel
  - Makefile fixes
  - removed unneeded files from tarball
* Mon Nov 24 2008 sf@suse.de
- new version 1.0.3 (bnc #438954)
  - add working tools
  - add required libraries
  - add hbaapi
  - add required headers from dcbd
* Wed Sep 24 2008 hare@suse.de
- Initial package (FATE#303914)
